==> jc-1.4.0.tar.gz: java/util/logging/ConsoleHandler.h <==
// public class java.util.logging.ConsoleHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 423d98bd7f8befd3 java_util_logging_ConsoleHandler
// @dep_class ddab973c71748871 java_util_logging_Handler
// @dep_class ed1d4146c2efe28e java_util_logging_StreamHandler

// header file dependencies
// @dep_header java_util_logging_StreamHandler

#include "java/util/logging/StreamHandler.h"

#ifndef _JC_java_util_logging_ConsoleHandler_H_
#define _JC_java_util_logging_ConsoleHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_ConsoleHandler$sub_refs	_jc_java_util_logging_ConsoleHandler$sub_refs;
typedef struct _jc_java_util_logging_ConsoleHandler$sub_nonrefs	_jc_java_util_logging_ConsoleHandler$sub_nonrefs;
typedef struct _jc_java_util_logging_ConsoleHandler$refs	_jc_java_util_logging_ConsoleHandler$refs;
typedef struct _jc_java_util_logging_ConsoleHandler$nonrefs	_jc_java_util_logging_ConsoleHandler$nonrefs;
typedef struct _jc_java_util_logging_ConsoleHandler$object	_jc_java_util_logging_ConsoleHandler$object;

typedef struct _jc_java_util_logging_ConsoleHandler$fields_struct	_jc_java_util_logging_ConsoleHandler$fields_struct;
typedef const struct _jc_java_util_logging_ConsoleHandler$vmethods	_jc_java_util_logging_ConsoleHandler$vmethods;
typedef const struct _jc_java_util_logging_ConsoleHandler$vtable	_jc_java_util_logging_ConsoleHandler$vtable;
typedef const struct _jc_java_util_logging_ConsoleHandler$vtype	_jc_java_util_logging_ConsoleHandler$vtype;

// Class fields structure
struct _jc_java_util_logging_ConsoleHandler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24SimpleFormatter;
};
extern _jc_java_util_logging_ConsoleHandler$fields_struct _jc_java_util_logging_ConsoleHandler$class_fields;

// Constructors
extern void _jc_java_util_logging_ConsoleHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *);

// Virtual methods
extern void _jc_java_util_logging_ConsoleHandler$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *);
extern void _jc_java_util_logging_ConsoleHandler$method$publish$f944ff14284acf4e(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *, struct _jc_java_util_logging_LogRecord$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_ConsoleHandler$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_logging_ConsoleHandler$method_info$publish$f944ff14284acf4e;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_util_logging_ConsoleHandler$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_java_util_logging_ConsoleHandler$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *);
	void	(*publish$f944ff14284acf4e)(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *, struct _jc_java_util_logging_LogRecord$object *);
};

// Vtable
struct _jc_java_util_logging_ConsoleHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Handler$vmethods	java_util_logging_Handler;
	_jc_java_util_logging_StreamHandler$vmethods	java_util_logging_StreamHandler;
	_jc_java_util_logging_ConsoleHandler$vmethods	java_util_logging_ConsoleHandler;
};

// Vtype
struct _jc_java_util_logging_ConsoleHandler$vtype {
	_jc_type			type;
	_jc_java_util_logging_ConsoleHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_ConsoleHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_ConsoleHandler$refs {
    _jc_java_util_logging_ConsoleHandler$sub_refs	java_util_logging_ConsoleHandler;
    _jc_java_util_logging_StreamHandler$sub_refs	java_util_logging_StreamHandler;
    _jc_java_util_logging_Handler$sub_refs	java_util_logging_Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_ConsoleHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_ConsoleHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Handler$sub_nonrefs	java_util_logging_Handler;
    _jc_java_util_logging_StreamHandler$sub_nonrefs	java_util_logging_StreamHandler;
    _jc_java_util_logging_ConsoleHandler$sub_nonrefs	java_util_logging_ConsoleHandler;
};

// Object instance structure
struct _jc_java_util_logging_ConsoleHandler$object {
	_jc_java_util_logging_ConsoleHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_ConsoleHandler$vtype	*vtype;
	_jc_java_util_logging_ConsoleHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_ConsoleHandler$vtype _jc_java_util_logging_ConsoleHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_ConsoleHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_ConsoleHandler$class_object;

#endif	/* _JC_java_util_logging_ConsoleHandler_H_ */

==> jc-1.4.6.tar.gz: java/util/logging/ConsoleHandler.h <==
// public class java.util.logging.ConsoleHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 423d98bd7f8befd3 java_util_logging_ConsoleHandler
// @dep_class ddab973c71748871 java_util_logging_Handler
// @dep_class ed1d4146c2efe28e java_util_logging_StreamHandler

// header file dependencies
// @dep_header java_util_logging_StreamHandler

#include "java/util/logging/StreamHandler.h"

#ifndef _JC_java_util_logging_ConsoleHandler_H_
#define _JC_java_util_logging_ConsoleHandler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_ConsoleHandler$sub_refs	_jc_java_util_logging_ConsoleHandler$sub_refs;
typedef struct _jc_java_util_logging_ConsoleHandler$sub_nonrefs	_jc_java_util_logging_ConsoleHandler$sub_nonrefs;
typedef struct _jc_java_util_logging_ConsoleHandler$refs	_jc_java_util_logging_ConsoleHandler$refs;
typedef struct _jc_java_util_logging_ConsoleHandler$nonrefs	_jc_java_util_logging_ConsoleHandler$nonrefs;
typedef struct _jc_java_util_logging_ConsoleHandler$object	_jc_java_util_logging_ConsoleHandler$object;

typedef struct _jc_java_util_logging_ConsoleHandler$fields_struct	_jc_java_util_logging_ConsoleHandler$fields_struct;
typedef const struct _jc_java_util_logging_ConsoleHandler$vmethods	_jc_java_util_logging_ConsoleHandler$vmethods;
typedef const struct _jc_java_util_logging_ConsoleHandler$vtable	_jc_java_util_logging_ConsoleHandler$vtable;
typedef const struct _jc_java_util_logging_ConsoleHandler$vtype	_jc_java_util_logging_ConsoleHandler$vtype;

// Class fields structure
struct _jc_java_util_logging_ConsoleHandler$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24util__24logging__24SimpleFormatter;
};
extern _jc_java_util_logging_ConsoleHandler$fields_struct _jc_java_util_logging_ConsoleHandler$class_fields;

// Constructors
extern void _jc_java_util_logging_ConsoleHandler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_logging_ConsoleHandler$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_logging_ConsoleHandler$method$publish$f944ff14284acf4e(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_ConsoleHandler$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_java_util_logging_ConsoleHandler$method_info$publish$f944ff14284acf4e;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_java_util_logging_ConsoleHandler$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_logging_ConsoleHandler$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *) _JC_JCNI_ATTR;
	void	(*publish$f944ff14284acf4e)(_jc_env *, struct _jc_java_util_logging_ConsoleHandler$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_logging_ConsoleHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Handler$vmethods	java_util_logging_Handler;
	_jc_java_util_logging_StreamHandler$vmethods	java_util_logging_StreamHandler;
	_jc_java_util_logging_ConsoleHandler$vmethods	java_util_logging_ConsoleHandler;
};

// Vtype
struct _jc_java_util_logging_ConsoleHandler$vtype {
	_jc_type			type;
	_jc_java_util_logging_ConsoleHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_ConsoleHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_logging_ConsoleHandler$refs {
    _jc_java_util_logging_ConsoleHandler$sub_refs	java_util_logging_ConsoleHandler;
    _jc_java_util_logging_StreamHandler$sub_refs	java_util_logging_StreamHandler;
    _jc_java_util_logging_Handler$sub_refs	java_util_logging_Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_ConsoleHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_ConsoleHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Handler$sub_nonrefs	java_util_logging_Handler;
    _jc_java_util_logging_StreamHandler$sub_nonrefs	java_util_logging_StreamHandler;
    _jc_java_util_logging_ConsoleHandler$sub_nonrefs	java_util_logging_ConsoleHandler;
};

// Object instance structure
struct _jc_java_util_logging_ConsoleHandler$object {
	_jc_java_util_logging_ConsoleHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_ConsoleHandler$vtype	*vtype;
	_jc_java_util_logging_ConsoleHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_ConsoleHandler$vtype _jc_java_util_logging_ConsoleHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_ConsoleHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_ConsoleHandler$class_object;

#endif	/* _JC_java_util_logging_ConsoleHandler_H_ */
